﻿//
// In order to convert some functionality to Visual C#, the Java Language Conversion Assistant
// creates "support classes" that duplicate the original functionality.  
//
// Support classes replicate the functionality of the original code, but in some cases they are 
// substantially different architecturally. Although every effort is made to preserve the 
// original architecture of the application in the converted project, the user should be aware that 
// the primary goal of these support classes is to replicate functionality, and that at times 
// the architecture of the resulting solution may differ somewhat.
//

using System;

/// <summary>
/// Contains conversion support elements such as classes, interfaces and static methods.
/// </summary>
internal class SupportClass
{
	/// <summary>
	/// Gives support functions to Http internet connections.
	/// </summary>
    internal class URLConnectionSupport
	{
		/// <summary>
		/// Sets the request property for the specified key
		/// </summary>
		/// <param name="connection">Connection used to assign the property value</param>
		/// <param name="key">Property name to obtain the property value</param>
		/// <param name="keyValue">The value to associate with the specified property</param>
		public static void SetRequestProperty(System.Net.HttpWebRequest connection, System.String key, System.String keyValue) 
		{
			if (connection.HaveResponse)
				throw new System.FieldAccessException("Already connected");
		}

		/// <summary>
		/// Gets the request property for the specified key
		/// </summary>
		/// <param name="connection">Connection used to obtain the property value</param>
		/// <param name="key">Property name to return it's property value</param>
		/// <returns>The value associated with the specified property</returns>
		public static System.String GetRequestProperty(System.Net.HttpWebRequest connection, System.String key) 
		{
			if (connection.HaveResponse)
				throw new System.FieldAccessException("Already connected");
			return null;
		}

		/// <summary>
		/// Receives a key and returns it's default property value
		/// </summary>
		/// <param name="key">Key name to obtain the default request value</param>
		/// <returns>The default value associated with the property</returns>
		public static System.String GetDefaultRequestProperty(System.String key) 
		{
			return null;
		}

		/// <summary> 
		/// Gets the value of the "Content-Encoding" property from the collection of headers associated with the specified HttpWebRequest
		/// </summary>
		/// <param name="request">Instance of HttpWebRequest to get the headers from</param>
		/// <returns>The value of the "Content-Encoding" property if found, otherwise returns null</returns>
		public static System.String GetContentEncoding(System.Net.HttpWebRequest request)
		{
			System.String resultContentEncoding;
			try 
			{
				resultContentEncoding = request.GetResponse().Headers.Get("Content-Encoding");
			}
			catch
			{
				resultContentEncoding = null;
			}
			return resultContentEncoding;
		}

		/// <summary>
		/// Gets the sending date of the resource referenced by the HttpRequest
		/// </summary>
		/// <param name="request">Instance of HttpWebRequest to get the date from</param>
		/// <returns>The sending date of the resource if found, otherwise 0</returns>
		public static long GetSendingDate(System.Net.HttpWebRequest request)
		{
			long headerDate;
			try
			{
				headerDate = System.DateTime.Parse(request.Headers.Get("Date")).Ticks;
			}
			catch
			{
				headerDate = 0;
			}
			return headerDate;
		}

		/// <summary>
		/// Gets the key for the specified index - 1 from the KeysCollection of the specified HttpWebRequest's Headers property
		/// </summary>
		/// <param name="request">Instance HttpWebRequest to get the key from</param>
		/// <param name="indexField">Index of the field to get the corresponding key</param>
		/// <returns>The key for the specified index if found, otherwise null</returns>
		public static System.String GetHeaderFieldKey(System.Net.HttpWebRequest request, int indexField)
		{
			string headerKey;
			try
			{
				headerKey = request.GetResponse().Headers.Keys.Get(indexField - 1);
			}
			catch
			{
				headerKey = null;
			}
			return headerKey;
		}

		/// <summary>
		/// Gets the value of the "Last-Modified" property from the collection of headers associated with the specified HttWebRequest
		/// </summary>
		/// <param name="request">Instance of HttpWebRequest to get the headers from</param>
		/// <returns>The value of the "Last-Modified" property if found, otherwise returns null</returns>
		public static long GetLastModifiedHeaderField(System.Net.HttpWebRequest request)
		{
			long fieldHeaderDate;
			try
			{
				fieldHeaderDate = System.DateTime.Parse(request.GetResponse().Headers.Get("Last-Modified")).Ticks;
			}
			catch
			{
				fieldHeaderDate = 0;
			}
			return fieldHeaderDate;
		}

		/// <summary>
		/// Gets the value of the named field parsed as date in milliseconds
		/// </summary>
		/// <param name="request">Instance of System.Net.HttpWebRequest to get the headers from</param>
		/// <param name="fieldName">Name of the header field</param>
		/// <param name="defaultValue">A default value to return if the value does not exist in the headers</param>
		/// <returns></returns>
		public static long GetHeaderFieldDate(System.Net.HttpWebRequest request, string fieldName, long defaultValue)
		{
			long fieldHeaderDate;
			try
			{
				fieldHeaderDate = System.DateTime.Parse(request.GetResponse().Headers.Get(fieldName)).Ticks;
			}
			catch
			{
				fieldHeaderDate = defaultValue;
			}
			return fieldHeaderDate;
		}
	}

	/*******************************/
	/// <summary>
	/// Writes the exception stack trace to the received stream
	/// </summary>
	/// <param name="throwable">Exception to obtain information from</param>
	/// <param name="stream">Output sream used to write to</param>
	internal static void WriteStackTrace(System.Exception throwable, System.IO.TextWriter stream)
	{
		stream.Write(throwable.StackTrace);
		stream.Flush();
	}

}
